/*The Design Ball
 * By Sascha de Waal
 */

#include <WaveHC.h>
#include <WaveUtil.h>
#include <Adafruit_NeoPixel.h>
#include "I2Cdev.h"
#include "MPU6050.h"

MPU6050 accelgyro;

SdReader card; 
FatVolume vol;   
FatReader root; 
WaveHC wave; 

int16_t ax, ay, az;
int16_t gx, gy, gz;
uint8_t dirLevel; 
dir_t dirBuf; 

#define OUTPUT_READABLE_ACCELGYRO

Adafruit_NeoPixel pixels = Adafruit_NeoPixel(65, 6, NEO_GRB + NEO_KHZ800);

int state = 2;
int talkedTime = 0;

int score = 00;
float playPos = 0;
int ran = 0;
int played = 0;

void setup() {

  pixels.begin(); 
  accelgyro.initialize();
  ResetLight();

  card.init();
  card.partialBlockRead(true);
  
  uint8_t part;
  for (part = 0; part < 5; part++) {
    if (vol.init(card, part)) 
      break;
  }

  SetScore(score,playPos);
  
  root.openRoot(vol);
}


void loop() {


  if (state == 0){
    root.rewind();
    ask(root);
  }
  if (state == 1){
    userTak();
  }
  if (state == 2){
    play();
  }
  
}

void SetScore(int score, int startPos){
  for(int i=0;i<65;i++){
      pixels.setPixelColor(i, pixels.Color(0,0,0));
  }
  
  for(float i=startPos;i<score+1+startPos;i++){

    int kleineRing = round((i/50.0)*19.0);
    if (kleineRing > 19) kleineRing -= 20;
    if (kleineRing < 00) kleineRing += 20;
    pixels.setPixelColor(kleineRing, pixels.Color(0,50,0));
    pixels.setPixelColor(kleineRing+20, pixels.Color(0,50,0));

    int groteRing = round((i/50.0)*24.0)+40;
    if (groteRing > 64) groteRing -= 25;
    if (groteRing < 40) groteRing += 25;
    pixels.setPixelColor(groteRing, pixels.Color(0,50,0));
    
  }
  pixels.show();
}

void ResetLight(){
  for(int i=0;i<65;i++){
      pixels.setPixelColor(i, pixels.Color(0,0,0));
  }
  pixels.show();
}

void play(){
  
  
  accelgyro.getRotation(&gx, &gy, &gz);


  if(gz > 3000){
    playPos-= 0.25;
    if (playPos < 0) playPos = 50;
    SetScore(score,playPos);
    played ++;
  }

  if(gz < -3000){
    playPos+= 0.25;
    if (playPos > 50) playPos = 0;
    SetScore(score,playPos);
    played ++;
  }

  if (played > 5000 && score < 65){
    played = 0;
    state = 0;
  }
  
}

void userTak(){

    //int sensorValue = analogRead(3);
    //if (talkedTime > 65){
      pixels.setPixelColor(talkedTime, pixels.Color(0,0,50));
      pixels.show();
      talkedTime ++;
      delay(400);
      
      if (talkedTime > 65){
        ResetLight();
        delay(200);
        accelgyro.initialize();
        talkedTime = 0;
        played = 0;
        playPos = 0;
        state = 2;
        score+=10;
      }
    //}
  
  
}

void ask(FatReader &dir) {
  for(int i=0;i<65;i++){
      pixels.setPixelColor(i, pixels.Color(50,0,0));
  }
  pixels.show();
  delay(500);
  
  FatReader file;

  accelgyro.getRotation(&gx, &gy, &gz);
  randomSeed(gx);
  int choose = random(1,21);
  int index = 0;
  while (dir.readDir(dirBuf) > 0) { 
    file.open(vol, dirBuf);
    
    //play
    if (!file.isDir() && index == choose) { 
      printEntryName(dirBuf);
      if (wave.create(file)) { 
        wave.play();
        uint8_t n = 0;
        while (wave.isplaying) {
          delay(100);
        }
        state = 1;       
      }
    }

    index ++;
  }
}

